# -*- coding: UTF-8 -*-
__author__ = "余洋"
__doc__ = "Mode"
"""
  * @File    :   Mode.py
  * @Time    :   2023/04/25 23:59:52
  * @Author  :   余洋
  * @Version :   1.0
  * @Contact :   yuyangit.0515@qq.com
  * @License :   (C)Copyright 2019-2024, 希洋 (Ship of Ocean)
  * @Desc    :   None
"""

from enum import IntEnum


class Mode(IntEnum):
    SIMPLE = 0
    FULL = 1
